==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/da.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Ukendt adresse",
    "No result." : "Intet resultat",
    "Malformed JSON data." : "Fejl i JSON dataformat.",
    "Error" : "Fejl",
    "Weather status" : "Status for vejret",
    "Weather status in your dashboard" : "Status for vejret på dit kontrolpanel",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Vejrstatus integreret i Dashboard-appen.\nDen geografiske placering kan bestemmes automatisk eller manuelt. En 6 timers prognose vises derefter.\nDenne status kan også integreres andre steder som f.eks. Kalender-appen.",
    "Detect location" : "Find min lokalitet",
    "Set custom address" : "Angiv brugerdefineret adresse",
    "Favorites" : "Favoritter",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} skyfri himmel senere i dag",
    "{temperature} {unit} clear sky" : "{temperature} {unit} skyfri himmel",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} overskyet senere i dag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} overskyet",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} pænt vejr senere i dag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} pænt vejr",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} delvist overskyet senere i dag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} delvis overskyet",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} tåget senere i dag",
    "{temperature} {unit} foggy" : "{temperature} {unit} tåget",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} let regn senere i dag",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} let regn",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} let regn senere i dag",
    "{temperature} {unit} rainfall" : "{temperature} {unit} regn",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} kraftig regn senere i dag",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} kraftig regn",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} regnbyger senere i dag",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} regnbyger",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lette regnbyger senere i dag",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lette regnbyger",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} kraftige regnbyger senere i dag",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} kraftige regnbyger",
    "More weather for {adr}" : "Yderligere vejr for {adr}",
    "Loading weather" : "Henter vejrudsigt",
    "Set location for weather" : "Lokalitet for vejret",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add as favorite" : "Tilføj til favoritter",
    "You are not logged in." : "Du er ikke logget på.",
    "There was an error getting the weather status information." : "Der skete en fejl under hentning af vejudsigten.",
    "No weather information found" : "Ingen vejrudsigt fundet",
    "Location not found" : "Den valgte lokalitet blev ikke fundet",
    "There was an error setting the location address." : "Der opstod en fejl ved valg af lokalitetsadresse",
    "There was an error setting the location." : "Der opstod en fejl ved valg af lokalitet",
    "There was an error saving the mode." : "Tilstanden kunne ikke gemmes.",
    "There was an error using personal address." : "Der skete en fejl i forsøget på at anvende personlig adresse."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.16.tgz: nextcloud/apps/weather_status/l10n/da.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Ukendt adresse",
    "No result." : "Intet resultat",
    "Malformed JSON data." : "Fejl i JSON dataformat.",
    "Error" : "Fejl",
    "Weather status" : "Status for vejret",
    "Weather status in your dashboard" : "Status for vejret på dit kontrolpanel",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Vejrstatus integreret i Dashboard-appen.\nDen geografiske placering kan bestemmes automatisk eller manuelt. En 6 timers prognose vises derefter.\nDenne status kan også integreres andre steder som f.eks. Kalender-appen.",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} skyfri himmel senere i dag",
    "{temperature} {unit} clear sky" : "{temperature} {unit} skyfri himmel",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} overskyet senere i dag",
    "{temperature} {unit} cloudy" : "{temperature} {unit} overskyet",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} sne og torden senere idag",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} sne og torden",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} snebyger og torden senere i dag",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} snebyger og torden",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} snebyger, torden og polartusmørke senere i dag",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} snebyger, torden og polartusmørke",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} snebyger senere i dag",
    "{temperature} {unit} snow showers" : "{temperature} {unit} snebyger",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} snebyger og polartusmørke senere i dag",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} snebyger og polartusmørke",
    "{temperature} {unit} snow later today" : "{temperature} {unit} sne senere i dag",
    "{temperature} {unit} snow" : "{temperature} {unit} sne",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} pænt vejr senere i dag",
    "{temperature} {unit} fair weather" : "{temperature} {unit} pænt vejr",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} delvist overskyet senere i dag",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} delvis overskyet",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} tåget senere i dag",
    "{temperature} {unit} foggy" : "{temperature} {unit} tåget",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} let regn senere i dag",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} let regn",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} let regn senere i dag",
    "{temperature} {unit} rainfall" : "{temperature} {unit} regn",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} kraftig regn senere i dag",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} kraftig regn",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} regnbyger senere i dag",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} regnbyger",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lette regnbyger senere i dag",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lette regnbyger",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} kraftige regnbyger senere i dag",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} kraftige regnbyger",
    "More weather for {adr}" : "Yderligere vejr for {adr}",
    "Loading weather" : "Henter vejrudsigt",
    "Set location for weather" : "Lokalitet for vejret",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add as favorite" : "Tilføj til favoritter",
    "You are not logged in." : "Du er ikke logget på.",
    "There was an error getting the weather status information." : "Der skete en fejl under hentning af vejudsigten.",
    "No weather information found" : "Ingen vejrudsigt fundet",
    "Location not found" : "Den valgte lokalitet blev ikke fundet",
    "There was an error setting the location address." : "Der opstod en fejl ved valg af lokalitetsadresse",
    "There was an error setting the location." : "Der opstod en fejl ved valg af lokalitet",
    "There was an error saving the mode." : "Tilstanden kunne ikke gemmes.",
    "There was an error using personal address." : "Der skete en fejl i forsøget på at anvende personlig adresse.",
    "Unknown weather code" : "Ukendt vejrkode",
    "Detect location" : "Find min lokalitet",
    "Set custom address" : "Angiv brugerdefineret adresse",
    "Favorites" : "Favoritter"
},
"nplurals=2; plural=(n != 1);");
